@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -50,6 +50,8 @@
 package com.openexchange.admin.rmi.impl;
 
 import static com.openexchange.java.Autoboxing.I;
+import static com.openexchange.java.Autoboxing.I2i;
+import static com.openexchange.java.Autoboxing.i2I;
 import java.io.IOException;
 import java.net.URI;
 import java.net.URISyntaxException;
@@ -69,7 +71,6 @@ import com.openexchange.admin.daemons.ClientAdminThread;
 import com.openexchange.admin.daemons.ClientAdminThreadExtended;
 import com.openexchange.admin.plugins.OXContextPluginInterface;
 import com.openexchange.admin.plugins.PluginException;
-import com.openexchange.admin.plugins.SQLQueryExtension;
 import com.openexchange.admin.rmi.OXContextInterface;
 import com.openexchange.admin.rmi.dataobjects.Context;
 import com.openexchange.admin.rmi.dataobjects.Credentials;
@@ -88,21 +89,23 @@ import com.openexchange.admin.rmi.exceptions.NoSuchDatabaseException;
 import com.openexchange.admin.rmi.exceptions.NoSuchFilestoreException;
 import com.openexchange.admin.rmi.exceptions.NoSuchReasonException;
 import com.openexchange.admin.rmi.exceptions.OXContextException;
+import com.openexchange.admin.rmi.exceptions.PoolException;
 import com.openexchange.admin.rmi.exceptions.StorageException;
 import com.openexchange.admin.rmi.extensions.OXCommonExtension;
 import com.openexchange.admin.storage.interfaces.OXContextStorageInterface;
-import com.openexchange.admin.storage.interfaces.OXToolStorageInterface;
 import com.openexchange.admin.storage.interfaces.OXUserStorageInterface;
 import com.openexchange.admin.storage.interfaces.OXUtilStorageInterface;
-import com.openexchange.admin.storage.mysqlStorage.OXToolMySQLStorage;
+import com.openexchange.admin.storage.sqlStorage.OXAdminPoolDBPoolExtension;
 import com.openexchange.admin.taskmanagement.TaskManager;
 import com.openexchange.admin.tools.DatabaseDataMover;
 import com.openexchange.admin.tools.FilestoreDataMover;
+import com.openexchange.admin.tools.PropertyHandlerExtended;
 import com.openexchange.caching.Cache;
 import com.openexchange.caching.CacheException;
 import com.openexchange.caching.CacheService;
 import com.openexchange.groupware.contexts.impl.ContextException;
 import com.openexchange.groupware.contexts.impl.ContextStorage;
+import com.openexchange.tools.pipesnfilters.Filter;
 
 public class OXContext extends OXContextCommonImpl implements OXContextInterface {
 
@@ -112,15 +115,21 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
 
     private final Log log = LogFactory.getLog(this.getClass());
 
+	private OXAdminPoolDBPoolExtension pool;
+
+
     public OXContext(final BundleContext context) throws StorageException {
         super();
         this.context = context;
+        this.pool = new OXAdminPoolDBPoolExtension(new PropertyHandlerExtended(System.getProperties()));
+        
         if (log.isDebugEnabled()) {
             log.debug("Class loaded: " + this.getClass().getName());
         }
     }
 
-    public void change(final Context ctx, final Credentials auth) throws RemoteException, InvalidCredentialsException, NoSuchContextException, StorageException, InvalidDataException {
+    public void change(final Context ctx, Credentials auth) throws RemoteException, InvalidCredentialsException, NoSuchContextException, StorageException, InvalidDataException {
+        auth = auth == null ? new Credentials("","") : auth;
         try {
             doNullCheck(ctx);
         } catch (final InvalidDataException e1) {
@@ -186,9 +195,10 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
         return createcommon(ctx, admin_user, null, null, auth);
     }
 
-    public Context create(final Context ctx, final User admin_user,final String access_combination_name, final Credentials auth)
+    public Context create(final Context ctx, final User admin_user,final String access_combination_name, Credentials auth)
         throws RemoteException, StorageException,InvalidCredentialsException, InvalidDataException,    ContextExistsException {
-
+        
+        auth = auth == null ? new Credentials("","") : auth;
         // Resolve access rights by name
         try {
             doNullCheck(admin_user, access_combination_name);
@@ -215,8 +225,9 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
         return createcommon(ctx, admin_user, null, access, auth);
     }
 
-    public Context create(final Context ctx, final User admin_user,final UserModuleAccess access, final Credentials auth)
+    public Context create(final Context ctx, final User admin_user,final UserModuleAccess access, Credentials auth)
         throws RemoteException,StorageException, InvalidCredentialsException,InvalidDataException, ContextExistsException {
+        auth = auth == null ? new Credentials("","") : auth;
 
         try {
             doNullCheck(admin_user, access);
@@ -229,11 +240,12 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
 
     }
 
-    public void delete(Context ctx, Credentials auth) throws RemoteException, InvalidCredentialsException, NoSuchContextException, StorageException, DatabaseUpdateException, InvalidDataException {
+    public void delete(final Context ctx, Credentials auth) throws RemoteException, InvalidCredentialsException, NoSuchContextException, StorageException, DatabaseUpdateException, InvalidDataException {
+        auth = auth == null ? new Credentials("","") : auth;
         try {
             doNullCheck(ctx);
-        } catch (InvalidDataException e) {
-            InvalidDataException e1 = new InvalidDataException("Context is null");
+        } catch (final InvalidDataException e) {
+            final InvalidDataException e1 = new InvalidDataException("Context is null");
             log.error(e1.getMessage(), e1);
             throw e1;
         }
@@ -252,7 +264,7 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
                 if (tool.checkAndUpdateSchemaIfRequired(ctx)) {
                     throw new DatabaseUpdateException("Database is locked or is now beeing updated, please try again later");
                 }
-            } catch (StorageException e) {
+            } catch (final StorageException e) {
                 // Context deletion should be a robust process. Therefore not failing if the schema is not up
             }
 
@@ -274,10 +286,25 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
         }
 
         try {
-            ContextStorage.getInstance().invalidateContext(ctx.getId().intValue());
+        	int contextID = ctx.getId().intValue();
+            ContextStorage.getInstance().invalidateContext(contextID);
+            final CacheService cacheService = AdminDaemon.getService(SYMBOLIC_NAME_CACHE, NAME_OXCACHE, context, CacheService.class);
+            if (null != cacheService) {
+                try {
+                    final Cache cache = cacheService.getCache("MailAccount");
+                    cache.invalidateGroup(ctx.getId().toString());
+                } catch (final CacheException e) {
+                    log.error(e.getMessage(), e);
+                } finally {
+                    AdminDaemon.ungetService(SYMBOLIC_NAME_CACHE, NAME_OXCACHE, context);
+                }
+            }
+			pool.resetPoolMappingForContext(contextID);
         } catch (final ContextException e) {
             log.error("Error invalidating context "+ctx.getId()+" in ox context storage",e);
-        }
+        } catch (PoolException e) {
+        	log.info("Could not reset PoolMapping for context "+ctx.getId()+" while deleting it. Should not have been mapped then.");
+		}
     }
 
     public void disable(final Context ctx, final Credentials auth) throws RemoteException, InvalidCredentialsException, NoSuchContextException, StorageException, InvalidDataException, NoSuchReasonException, OXContextException {
@@ -285,7 +312,8 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
         disable(ctx, reason, auth);
     }
 
-    private void disable(final Context ctx, final MaintenanceReason reason, final Credentials auth) throws RemoteException, InvalidCredentialsException, NoSuchContextException, StorageException, InvalidDataException, NoSuchReasonException, OXContextException {
+    private void disable(final Context ctx, final MaintenanceReason reason, Credentials auth) throws RemoteException, InvalidCredentialsException, NoSuchContextException, StorageException, InvalidDataException, NoSuchReasonException, OXContextException {
+        auth = auth == null ? new Credentials("","") : auth;
         try {
             doNullCheck(ctx, reason);
             doNullCheck(reason.getId());
@@ -341,7 +369,8 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
         disableAll(reason, auth);
     }
 
-    private void disableAll(final MaintenanceReason reason, final Credentials auth) throws RemoteException, StorageException, InvalidCredentialsException, InvalidDataException, NoSuchReasonException {
+    private void disableAll(final MaintenanceReason reason, Credentials auth) throws RemoteException, StorageException, InvalidCredentialsException, InvalidDataException, NoSuchReasonException {
+        auth = auth == null ? new Credentials("","") : auth;
         try{
             doNullCheck(reason);
             doNullCheck(reason.getId());
@@ -388,7 +417,8 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
         // END OF CACHE
     }
 
-    public void enable(final Context ctx, final Credentials auth) throws RemoteException, InvalidCredentialsException, NoSuchContextException, StorageException, InvalidDataException {
+    public void enable(final Context ctx, Credentials auth) throws RemoteException, InvalidCredentialsException, NoSuchContextException, StorageException, InvalidDataException {
+        auth = auth == null ? new Credentials("","") : auth;
         try {
             doNullCheck(ctx);
         } catch (final InvalidDataException e1) {
@@ -423,8 +453,9 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
         }
     }
 
-    public void enableAll(final Credentials auth) throws RemoteException, StorageException, InvalidCredentialsException {
+    public void enableAll(Credentials auth) throws RemoteException, StorageException, InvalidCredentialsException {
         new BasicAuthenticator(context).doAuthentication(auth);
+        auth = auth == null ? new Credentials("","") : auth;
 
         try {
             final OXContextStorageInterface oxcox = OXContextStorageInterface.getInstance();
@@ -455,7 +486,8 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
         // END OF CACHE
     }
 
-    public Context[] getData(Context[] ctxs, final Credentials auth) throws RemoteException, InvalidCredentialsException, NoSuchContextException, StorageException, InvalidDataException {
+    public Context[] getData(final Context[] ctxs, Credentials auth) throws RemoteException, InvalidCredentialsException, NoSuchContextException, StorageException, InvalidDataException {
+        auth = auth == null ? new Credentials("","") : auth;
         try {
             try {
                 doNullCheck((Object[])ctxs);
@@ -517,7 +549,8 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
         return getData(new Context[]{ctx}, auth)[0];
     }
 
-    public Context[] list(final String search_pattern, final Credentials auth) throws RemoteException, StorageException, InvalidCredentialsException, InvalidDataException {
+    public Context[] list(final String search_pattern, Credentials auth) throws RemoteException, StorageException, InvalidCredentialsException, InvalidDataException {
+        auth = auth == null ? new Credentials("","") : auth;
         try {
             doNullCheck(search_pattern);
         } catch (final InvalidDataException e) {
@@ -532,8 +565,10 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
         try {
             final OXContextStorageInterface oxcox = OXContextStorageInterface.getInstance();
 
-            SQLQueryExtension temp = null;
-            SQLQueryExtension retval = null;
+            Filter<Context, Context> loader = null;
+            Filter<Integer, Integer> filter = null;
+            final ArrayList<Filter<Context, Context>> loaderFilter = new ArrayList<Filter<Context,Context>>();
+            final ArrayList<Filter<Integer, Integer>> contextFilter = new ArrayList<Filter<Integer,Integer>>();
             final ArrayList<Bundle> bundles = AdminDaemon.getBundlelist();
             for (final Bundle bundle : bundles) {
                 final String bundlename = bundle.getSymbolicName();
@@ -549,13 +584,13 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
                                     log.debug("Calling list for plugin: " + bundlename);
                                 }
                                 try {
-                                    temp = oxctx.list(search_pattern, auth);
-                                    if (null != temp) {
-                                        if (null != retval) {
-                                            retval = new SQLQueryExtension(retval.getTablename() + "," + temp.getTablename(), retval.getQuerypart() + temp.getQuerypart());
-                                        } else {
-                                            retval = temp;
-                                        }
+                                    filter = oxctx.filter(auth);
+                                    if (null != filter) {
+                                        contextFilter.add(filter);
+                                    }
+                                    loader = oxctx.list(search_pattern, auth);
+                                    if (null != loader) {
+                                        loaderFilter.add(loader);
                                     }
                                 } catch (final PluginException e) {
                                     log.error("Error while calling method list of plugin " + bundlename,e);
@@ -567,17 +602,7 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
                 }
             }
 
-            final Context[] ctxs;
-            if( null == retval ) {
-                ctxs = oxcox.listContext(search_pattern);
-            } else {
-                ctxs = oxcox.listContext(search_pattern, retval.getTablename(), retval.getQuerypart());
-            }
-            final List<Context> callGetDataPlugins = callGetDataPlugins(Arrays.asList(ctxs), auth, oxcox);
-            if (null != callGetDataPlugins)
-                return callGetDataPlugins.toArray(new Context[callGetDataPlugins.size()]);
-            return ctxs;
-
+            return oxcox.listContext(search_pattern, contextFilter, loaderFilter);
         } catch (final StorageException e) {
             log.error(e.getMessage(), e);
             throw e;
@@ -592,7 +617,8 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
         return list("*", auth);
     }
 
-    public Context[] listByDatabase(final Database db, final Credentials auth) throws RemoteException, StorageException, InvalidCredentialsException, InvalidDataException, NoSuchDatabaseException {
+    public Context[] listByDatabase(final Database db, Credentials auth) throws RemoteException, StorageException, InvalidCredentialsException, InvalidDataException, NoSuchDatabaseException {
+        auth = auth == null ? new Credentials("","") : auth;
         try {
             doNullCheck(db);
         } catch (final InvalidDataException e) {
@@ -609,14 +635,24 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
                 throw new NoSuchDatabaseException();
             }
             final OXContextStorageInterface oxcox = OXContextStorageInterface.getInstance();
-            return oxcox.searchContextByDatabase(db);
+
+            final List<Context> retval = new ArrayList<Context>();
+            final Context[] ret = oxcox.searchContextByDatabase(db);
+            final List<Context> callGetDataPlugins = callGetDataPlugins(Arrays.asList(ret), auth, oxcox);
+            if (null != callGetDataPlugins) {
+                retval.addAll(callGetDataPlugins);
+            } else {
+                retval.addAll(Arrays.asList(ret));
+            }
+            return retval.toArray(new Context[retval.size()]);
         } catch (final StorageException e) {
             log.error(e.getMessage(), e);
             throw e;
         }
     }
 
-    public Context[] listByFilestore(final Filestore filestore, final Credentials auth) throws RemoteException, StorageException, InvalidCredentialsException, InvalidDataException, NoSuchFilestoreException {
+    public Context[] listByFilestore(final Filestore filestore, Credentials auth) throws RemoteException, StorageException, InvalidCredentialsException, InvalidDataException, NoSuchFilestoreException {
+        auth = auth == null ? new Credentials("","") : auth;
         try {
             doNullCheck(filestore);
             doNullCheck(filestore.getId());
@@ -633,7 +669,15 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
                 throw new NoSuchFilestoreException();
             }
             final OXContextStorageInterface oxcox = OXContextStorageInterface.getInstance();
-            return oxcox.searchContextByFilestore(filestore);
+            final List<Context> retval = new ArrayList<Context>();
+            final Context[] ret = oxcox.searchContextByFilestore(filestore);
+            final List<Context> callGetDataPlugins = callGetDataPlugins(Arrays.asList(ret), auth, oxcox);
+            if (null != callGetDataPlugins) {
+                retval.addAll(callGetDataPlugins);
+            } else {
+                retval.addAll(Arrays.asList(ret));
+            }
+            return retval.toArray(new Context[retval.size()]);
         } catch (final StorageException e) {
             log.error(e.getMessage(), e);
             throw e;
@@ -648,7 +692,8 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
         return moveContextDatabase(ctx, db, reason, auth);
     }
 
-    private int moveContextDatabase(final Context ctx, final Database db, final MaintenanceReason reason, final Credentials auth) throws RemoteException, InvalidCredentialsException, NoSuchContextException, StorageException, InvalidDataException, DatabaseUpdateException, OXContextException {
+    private int moveContextDatabase(final Context ctx, final Database db, final MaintenanceReason reason, Credentials auth) throws RemoteException, InvalidCredentialsException, NoSuchContextException, StorageException, InvalidDataException, DatabaseUpdateException, OXContextException {
+        auth = auth == null ? new Credentials("","") : auth;
         try{
             doNullCheck(ctx,db,reason);
             doNullCheck(reason.getId());
@@ -713,11 +758,12 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
         return moveContextFilestore(ctx, dst_filestore, reason, auth);
     }
 
-    private int moveContextFilestore(final Context ctx, final Filestore dst_filestore, final MaintenanceReason reason, final Credentials auth) throws InvalidCredentialsException, NoSuchContextException, StorageException, InvalidDataException, NoSuchFilestoreException, OXContextException {
+    private int moveContextFilestore(final Context ctx, final Filestore dst_filestore, final MaintenanceReason reason, Credentials auth) throws InvalidCredentialsException, NoSuchContextException, StorageException, InvalidDataException, NoSuchFilestoreException, OXContextException {
+        auth = auth == null ? new Credentials("","") : auth;
         try {
             doNullCheck(ctx, dst_filestore, reason);
             doNullCheck(dst_filestore.getId(), reason.getId());
-        } catch (InvalidDataException e) {
+        } catch (final InvalidDataException e) {
             log.error("Invalid data sent by client!", e);
             throw e;
         }
@@ -758,7 +804,7 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
             }
 
             final OXUtilStorageInterface oxu = OXUtilStorageInterface.getInstance();
-            Filestore destFilestore = oxu.getFilestore(dst_filestore.getId().intValue());
+            final Filestore destFilestore = oxu.getFilestore(dst_filestore.getId().intValue());
             if (!oxu.hasSpaceForAnotherContext(destFilestore)) {
                 throw new StorageException("Destination filestore does not have enough space for another context.");
             }
@@ -805,7 +851,7 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
         validateloginmapping(ctx);
         final OXContextStorageInterface oxcox = OXContextStorageInterface.getInstance();
 
-        String DEFAULT_ACCESS_COMBINATION_NAME = ClientAdminThreadExtended.cache.getProperties().getProp("NEW_CONTEXT_DEFAULT_ACCESS_COMBINATION_NAME", "NOT_DEFINED");
+        final String DEFAULT_ACCESS_COMBINATION_NAME = ClientAdminThreadExtended.cache.getProperties().getProp("NEW_CONTEXT_DEFAULT_ACCESS_COMBINATION_NAME", "NOT_DEFINED");
         // If not defined or access combination name does NOT exist, use hardcoded fallback!
         UserModuleAccess createaccess = null;
         if( access == null ) {
@@ -822,14 +868,14 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
         ret = oxcox.create(ret, admin_user, createaccess);
         if( isAnyPluginLoaded() ) {
             try {
-                ret = (Context)callPluginMethod("postCreate", (Context)ret, admin_user, createaccess, auth);
-            } catch(StorageException e) {
+                ret = (Context)callPluginMethod("postCreate", ret, admin_user, createaccess, auth);
+            } catch(final StorageException e) {
                 log.error(e.getMessage(),e);
                 // callPluginMethod delete may fail here for what ever reason.
                 // this must not prevent us from cleaning up the rest
                 try {
                     callPluginMethod("delete", ctx, auth);
-                } catch (Exception e1) {
+                } catch (final Exception e1) {
                     log.error(e.getMessage(), e);
                 }
                 oxcox.delete(ret);
@@ -864,8 +910,9 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
         return src;
     }
 
-    public void changeModuleAccess(final Context ctx, final UserModuleAccess access,final Credentials auth)
+    public void changeModuleAccess(final Context ctx, final UserModuleAccess access,Credentials auth)
         throws RemoteException,InvalidCredentialsException, NoSuchContextException,    StorageException, InvalidDataException {
+        auth = auth == null ? new Credentials("","") : auth;
 
         try {
             doNullCheck(access);
@@ -890,8 +937,17 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
             final OXUserStorageInterface oxu = OXUserStorageInterface.getInstance();
 
             // change rights for all users in context to specified one in access
-            oxu.changeModuleAccess(ctx, oxu.getAll(ctx), access);
-
+            if (access.isPublicFolderEditable()) {
+                // publicFolderEditable can only be applied to the context administrator.
+                Integer[] userIds = i2I(oxu.getAll(ctx));
+                final int adminId = tool.getAdminForContext(ctx);
+                userIds = com.openexchange.tools.arrays.Arrays.remove(userIds, I(adminId));
+                oxu.changeModuleAccess(ctx, adminId, access);
+                access.setPublicFolderEditable(false);
+                oxu.changeModuleAccess(ctx, I2i(userIds), access);
+            } else {
+                oxu.changeModuleAccess(ctx, oxu.getAll(ctx), access);
+            }
         } catch (final StorageException e) {
             log.error(e.getMessage(), e);
             throw e;
@@ -899,9 +955,10 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
 
     }
 
-    public void changeModuleAccess(final Context ctx, final String access_combination_name,final Credentials auth)
+    public void changeModuleAccess(final Context ctx, final String access_combination_name,Credentials auth)
         throws RemoteException,InvalidCredentialsException, NoSuchContextException, StorageException, InvalidDataException {
 
+        auth = auth == null ? new Credentials("","") : auth;
 
         try {
             doNullCheck(access_combination_name);
@@ -936,8 +993,17 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
             final OXUserStorageInterface oxu = OXUserStorageInterface.getInstance();
 
             // change rights for all users in context to specified one in access combination name
-            oxu.changeModuleAccess(ctx, oxu.getAll(ctx), access);
-
+            if (access.isPublicFolderEditable()) {
+                // publicFolderEditable can only be applied to the context administrator.
+                Integer[] userIds = i2I(oxu.getAll(ctx));
+                final int adminId = tool.getAdminForContext(ctx);
+                userIds = com.openexchange.tools.arrays.Arrays.remove(userIds, I(adminId));
+                oxu.changeModuleAccess(ctx, adminId, access);
+                access.setPublicFolderEditable(false);
+                oxu.changeModuleAccess(ctx, I2i(userIds), access);
+            } else {
+                oxu.changeModuleAccess(ctx, oxu.getAll(ctx), access);
+            }
         } catch (final StorageException e) {
             log.error(e.getMessage(), e);
             throw e;
@@ -948,9 +1014,10 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
     /**
      * {@inheritDoc}
      */
-    public void downgrade(final Context ctx, final Credentials auth) throws
+    public void downgrade(final Context ctx, Credentials auth) throws
         RemoteException, InvalidCredentialsException,NoSuchContextException,
         StorageException, DatabaseUpdateException,InvalidDataException {
+        auth = auth == null ? new Credentials("","") : auth;
         try {
             doNullCheck(ctx);
         } catch (final InvalidDataException e1) {
@@ -985,8 +1052,9 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
         }
     }
 
-    public String getAccessCombinationName(final Context ctx, final Credentials auth)
+    public String getAccessCombinationName(final Context ctx, Credentials auth)
         throws RemoteException, InvalidCredentialsException,NoSuchContextException, StorageException, InvalidDataException {
+        auth = auth == null ? new Credentials("","") : auth;
 
         // Resolve admin user and get the module access from db and query cache for access combination name
         try {
@@ -1019,8 +1087,9 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
         }
     }
 
-    public UserModuleAccess getModuleAccess(final Context ctx, final Credentials auth)
+    public UserModuleAccess getModuleAccess(final Context ctx, Credentials auth)
         throws RemoteException, InvalidCredentialsException,NoSuchContextException, StorageException, InvalidDataException {
+        auth = auth == null ? new Credentials("","") : auth;
 
         try {
             doNullCheck(ctx);
@@ -1090,7 +1159,7 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
         return extensionsFound ? ctxs : null;
     }
 
-    private void addExtensionToContext(List<Context> ctxs, List<OXCommonExtension> retval, String bundlename) throws PluginException {
+    private void addExtensionToContext(final List<Context> ctxs, final List<OXCommonExtension> retval, final String bundlename) throws PluginException {
         if (null != retval) {
             if (retval.size() != ctxs.size()) {
                 throw new PluginException("After the call of plugin: " + bundlename + " the size of the context and the extensions differ");
@@ -1105,9 +1174,50 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
         }
     }
     
-    public int getAdminId(Context ctx, Credentials auth) throws RemoteException, InvalidCredentialsException, StorageException {
+    public int getAdminId(final Context ctx, Credentials auth) throws RemoteException, InvalidCredentialsException, StorageException, NoSuchContextException {
+        auth = auth == null ? new Credentials("","") : auth;
+        
         new BasicAuthenticator(context).doAuthentication(auth);
-        final OXToolStorageInterface oxtool = OXToolMySQLStorage.getInstance();
-        return oxtool.getAdminForContext(ctx);
+
+        try {
+            callPluginMethod("getAdminId", ctx, auth);
+        } catch (final StorageException e) {
+            log.error(e.getMessage(), e);
+            throw e;
+        }
+
+        if (!tool.existsContext(ctx)) {
+            throw new NoSuchContextException();
+        }
+
+        return tool.getAdminForContext(ctx);
+    }
+
+    public boolean exists(final Context ctx, Credentials auth) throws RemoteException, InvalidDataException, StorageException, InvalidCredentialsException {
+        auth = auth == null ? new Credentials("","") : auth;
+        new BasicAuthenticator(context).doAuthentication(auth);
+        
+        if(ctx == null) {
+            throw new InvalidDataException("Given context is invalid");
+        }
+
+        try {
+            callPluginMethod("exists", ctx, auth);
+        } catch (final StorageException e) {
+            log.error(e.getMessage(), e);
+            throw e;
+        }
+
+        if( null != ctx.getId() ) {
+            return tool.existsContext(ctx);
+        } else if( null != ctx.getName() ) {
+            return tool.existsContextName(ctx.getName());
+        } else {
+            throw new InvalidDataException("neither id or name is set in supplied context object");
+        }
+    }
+    
+    public boolean checkExists(final Context ctx, Credentials auth) throws RemoteException, InvalidDataException, StorageException, InvalidCredentialsException {
+        return exists(ctx, auth);
     }
 }
