@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -50,48 +50,56 @@
 package com.openexchange.admin.services;
 
 import java.util.Locale;
+import java.util.Map;
 import java.util.concurrent.ConcurrentHashMap;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
-
 import com.openexchange.i18n.I18nService;
 
+/**
+ * Registry for all found {@link I18nService} instances.
+ *
+ * @author <a href="mailto:marcus.klein@open-xchange.com">Marcus Klein</a>
+ */
 public class I18nServices {
 
     private static final Log LOG = LogFactory.getLog(I18nServices.class);
-
-    private final ConcurrentHashMap<Locale, I18nService> services = new ConcurrentHashMap<Locale, I18nService>();
-
+    private static final Locale DEFAULT_LOCALE = Locale.US;
     private static final I18nServices SINGLETON = new I18nServices();
 
+    private final Map<Locale, I18nService> services = new ConcurrentHashMap<Locale, I18nService>();
+
     private I18nServices() {
         super();
     }
 
-    public void addService(Locale locale, I18nService i18n) {
-        if (null !=services.put(locale, i18n)) {
-            LOG.warn("Another i18n translation service found for " + locale);
+    public void addService(final I18nService i18n) {
+        if (null != services.put(i18n.getLocale(), i18n)) {
+            LOG.warn("Another i18n translation service found for " + i18n.getLocale());
         }
     }
 
-    public void removeService(Locale locale, I18nService i18n) {
-        services.remove(locale, i18n);
+    public void removeService(final I18nService i18n) {
+        if (null == services.remove(i18n.getLocale())) {
+            LOG.warn("Unknown i18n translation service shut down for " + i18n.getLocale());
+        }
     }
 
     public static I18nServices getInstance() {
         return SINGLETON;
     }
 
-    public String translate(Locale locale, String toTranslate) {
-        I18nService service = services.get(locale);
+    public String translate(final Locale locale, final String toTranslate) {
+        final Locale loc = null == locale ? DEFAULT_LOCALE : locale;
+        final I18nService service = services.get(loc);
         if (null == service) {
-            if (!"en".equalsIgnoreCase(locale.getLanguage())) {
-                LOG.warn("No i18n service for locale " + locale + ".");
+            if (!"en".equalsIgnoreCase(loc.getLanguage())) {
+                LOG.warn("No i18n service for locale " + loc + ".");
             }
             return toTranslate;
         }
         if (!service.hasKey(toTranslate)) {
-            LOG.warn("I18n service for locale " + locale + " has no translation for \"" + toTranslate + "\".");
+            LOG.warn("I18n service for locale " + loc + " has no translation for \"" + toTranslate + "\".");
             return toTranslate;
         }
         return service.getLocalized(toTranslate);
