@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -177,6 +177,15 @@ public abstract class OXUtilStorageInterface {
      */
     public abstract Filestore getFilestore(final int id) throws StorageException;
 
+    /**
+     * Load a filestore. Specify whether the file store usage should be calculated by summing up all filestore usages.
+     * @param filestoreId
+     * @param loadUsage - Whether the usage must be determined. Note: This is very slow.
+     * @return
+     * @throws StorageException 
+     */
+    public abstract Filestore getFilestore(int filestoreId, boolean loadUsage) throws StorageException;
+    
     /**
      * Unregister filestore from configbdb
      * 
@@ -288,7 +297,7 @@ public abstract class OXUtilStorageInterface {
      *            a database id which is unregistered
      * @throws StorageException
      */
-    public abstract void unregisterDatabase(final int db_id) throws StorageException;
+    public abstract void unregisterDatabase(final int db_id, final boolean isMaster) throws StorageException;
 
     /**
      * Unregister a server from configdb
@@ -318,4 +327,6 @@ public abstract class OXUtilStorageInterface {
      * @throws StorageException
      */
     public abstract Server[] searchForServer(final String search_pattern) throws StorageException;
+
+   
 }
