@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -54,7 +54,7 @@ import com.openexchange.admin.rmi.dataobjects.Database;
 /**
  * Internally used object for getnextdbhandlebyweight method instead of
  */
-class DatabaseHandle extends Database {
+public class DatabaseHandle extends Database {
 
     private static final long serialVersionUID = -4816706296673058930L;
 
