@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -50,6 +50,7 @@
 package com.openexchange.admin.rmi;
 
 import static junit.framework.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertTrue;
 import static org.junit.Assert.fail;
 import java.net.MalformedURLException;
@@ -79,13 +80,10 @@ import com.openexchange.admin.rmi.exceptions.StorageException;
  */
 public class ContextTest extends AbstractTest {
 
-    public static Credentials DummyMasterCredentials(){
-        return new Credentials("oxadminmaster","secret");
-    }
-    
     public static junit.framework.Test suite() {
         return new JUnit4TestAdapter(ContextTest.class);
     }
+
     @Test
     public void testGetAdminId() throws Exception {
         final Credentials cred = DummyMasterCredentials();
@@ -107,6 +105,10 @@ public class ContextTest extends AbstractTest {
 
         Context srv_loaded = xctx.getData(ctx, cred);
 
+        assertEquals("lemon", srv_loaded.getUserAttribute("com.openexchange.test", "flavor"));
+        assertEquals("squishy", srv_loaded.getUserAttribute("com.openexchange.test", "texture"));
+        
+        
         assertTrue("Expected same context ids", ctx.getId().intValue() == srv_loaded.getId().intValue());
 
         String add_mapping = srv_loaded.getId().intValue() + "_" + System.currentTimeMillis();
@@ -114,12 +116,23 @@ public class ContextTest extends AbstractTest {
 
         String changed_context_name = srv_loaded.getName() + "_" + System.currentTimeMillis();
         srv_loaded.setName(changed_context_name);
-
+        
+        // And for good measure some dynamic attributes
+        
+        srv_loaded.setUserAttribute("com.openexchange.test", "flavor", "pistaccio");
+        srv_loaded.setUserAttribute("com.openexchange.test", "color", "green");
+        srv_loaded.setUserAttribute("com.openexchange.test", "texture", null);
+        
         // change context and load again
         xctx.change(srv_loaded, cred);
 
         Context edited_ctx = xctx.getData(ctx, cred);
 
+        assertEquals("pistaccio", srv_loaded.getUserAttribute("com.openexchange.test", "flavor"));
+        assertEquals("green", srv_loaded.getUserAttribute("com.openexchange.test", "color"));
+        assertEquals(null, srv_loaded.getUserAttribute("com.openexchange.test", "texture"));
+
+        
         // ids must be correct again and the mapping should now exist
         assertTrue("Expected same context ids", edited_ctx.getId().intValue() == srv_loaded.getId().intValue());
 
@@ -382,8 +395,12 @@ public class ContextTest extends AbstractTest {
         // then check if a database is in db for the new ctx, if not register
         // database first,
         // THEN we can add the context with its data
+        String dbhost = "localhost";
+        if(System.getProperty("rmi_test_dbhost")!=null){
+            dbhost = System.getProperty("rmi_test_dbhost");
+        }        
         if (oxu.listDatabase("test-ox-db", cred).length == 0) {
-            Database db = UtilTest.getTestDatabaseObject("localhost", "test-ox-db");
+            Database db = UtilTest.getTestDatabaseObject(dbhost, "test-ox-db");
             oxu.registerDatabase(db, cred);
         }
         
@@ -429,6 +446,8 @@ public class ContextTest extends AbstractTest {
     public static Context getTestContextObject(int context_id, long quota_max_in_mb) {
         Context ctx = getTestContextObject(context_id);        
         ctx.setMaxQuota(quota_max_in_mb);
+        ctx.setUserAttribute("com.openexchange.test", "flavor", "lemon");
+        ctx.setUserAttribute("com.openexchange.test", "texture", "squishy");
         return ctx;
     }
 
@@ -449,4 +468,18 @@ public class ContextTest extends AbstractTest {
         return ret;
     }
 
+    @Test
+    public void testExistsContext() throws Exception {
+        OXContextInterface ctxstub = (OXContextInterface) Naming.lookup(getRMIHostUrl() + OXContextInterface.RMI_NAME);
+        
+        final Credentials cred = DummyMasterCredentials();
+        Context ctxexists = getTestContextObject(cred);
+        addContext(ctxexists, getRMIHostUrl(), cred);
+        Context ctxnotexists = new Context();
+        ctxnotexists.setName("notexists.com");
+        
+        assertFalse("context must not exist", ctxstub.exists(ctxnotexists, cred));
+        assertTrue("context must exist", ctxstub.exists(ctxexists, cred));
+    }
+
 }
