@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -52,20 +52,15 @@ package com.openexchange.admin.rmi;
 
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertNotNull;
 import static org.junit.Assert.assertTrue;
 import static org.junit.Assert.fail;
-
 import java.net.MalformedURLException;
 import java.rmi.Naming;
 import java.rmi.NotBoundException;
 import java.rmi.RemoteException;
 import java.util.Vector;
-
 import junit.framework.JUnit4TestAdapter;
-
 import org.junit.Test;
-
 import com.openexchange.admin.rmi.dataobjects.Database;
 import com.openexchange.admin.rmi.dataobjects.Filestore;
 import com.openexchange.admin.rmi.dataobjects.MaintenanceReason;
@@ -86,10 +81,16 @@ public class UtilTest extends AbstractTest {
 		return new JUnit4TestAdapter(UtilTest.class);
 	}
     
-    public static Filestore getTestFilestoreObject(String name,String url) throws Exception{
+    public static Filestore getTestFilestoreObject(String name,String relativePath) throws Exception{
         Filestore client_st = new Filestore();
         
+        String storepath = "/tmp/";
+        if(System.getProperty("rmi_test_storepath")!=null){
+            storepath = System.getProperty("rmi_test_storepath");
+        }        
         // create dir 
+        String url = "file:/" + storepath + "/" + relativePath;
+        url = url.replaceAll("//", "/");
         java.net.URI uri = new java.net.URI(url);
         client_st.setUrl(uri.toString());
         new java.io.File(uri.getPath()).mkdir();
@@ -109,7 +110,11 @@ public class UtilTest extends AbstractTest {
         client_db.setLogin("openexchange");
         client_db.setMaster(true);
         client_db.setMaxUnits(1000);
-        client_db.setPassword("secret");
+        String dbpw = "secret";
+        if(System.getProperty("rmi_test_dbpw")!=null){
+            dbpw = System.getProperty("rmi_test_dbpw");
+        }        
+        client_db.setPassword(dbpw);
         client_db.setPoolHardLimit(20);
         client_db.setPoolInitial(2);
         client_db.setPoolMax(100);
@@ -443,7 +448,7 @@ public class UtilTest extends AbstractTest {
             assertTrue(true);
         }
         
-        client_st = getTestFilestoreObject("testcase_registerfilestore_disc_"+System.currentTimeMillis(),"file:/tmp/disc_"+System.currentTimeMillis());
+        client_st = getTestFilestoreObject("testcase_registerfilestore_disc_"+System.currentTimeMillis(),"disc_"+System.currentTimeMillis());
          
         client_st.setId(oxu.registerFilestore(client_st,ContextTest.DummyMasterCredentials()).getId());
         
@@ -454,7 +459,7 @@ public class UtilTest extends AbstractTest {
             assertTrue(true);
         }
         
-        Filestore[] srv_stores = oxu.listFilestore("file:/tmp/disc_*",ContextTest.DummyMasterCredentials());
+        Filestore[] srv_stores = oxu.listFilestore("*disc_*",ContextTest.DummyMasterCredentials());
         
         // now check if added filestore was correctly registered to the system        
         boolean found_store = false;
@@ -474,11 +479,11 @@ public class UtilTest extends AbstractTest {
     public void testChangeFilestore() throws Exception {
         OXUtilInterface oxu = getUtilClient();
         
-        Filestore client_st = getTestFilestoreObject("testcase_registerfilestore_disc_"+System.currentTimeMillis(),"file:/tmp/disc_"+System.currentTimeMillis());
+        Filestore client_st = getTestFilestoreObject("testcase_registerfilestore_disc_"+System.currentTimeMillis(),"disc_"+System.currentTimeMillis());
          
         client_st.setId(oxu.registerFilestore(client_st,ContextTest.DummyMasterCredentials()).getId());
         
-        Filestore[] srv_stores = oxu.listFilestore("file:/tmp/disc_*",ContextTest.DummyMasterCredentials());
+        Filestore[] srv_stores = oxu.listFilestore("*disc_*",ContextTest.DummyMasterCredentials());
         
         // now check if added filestore was correctly registered to the system        
         boolean found_store = false;
@@ -503,7 +508,7 @@ public class UtilTest extends AbstractTest {
         // change store on server
         oxu.changeFilestore(client_st,ContextTest.DummyMasterCredentials());
         
-        srv_stores = oxu.listFilestore("file:/tmp/disc_*",ContextTest.DummyMasterCredentials());
+        srv_stores = oxu.listFilestore("*disc_*",ContextTest.DummyMasterCredentials());
         
         // now check if added filestore was correctly registered to the system        
         found_store = false;
@@ -524,11 +529,11 @@ public class UtilTest extends AbstractTest {
     public void testListFilestores() throws Exception {
        OXUtilInterface oxu = getUtilClient();
         
-        Filestore client_st = getTestFilestoreObject("testcase_registerfilestore_disc_"+System.currentTimeMillis(),"file:/tmp/disc_"+System.currentTimeMillis());
+        Filestore client_st = getTestFilestoreObject("testcase_registerfilestore_disc_"+System.currentTimeMillis(),"disc_"+System.currentTimeMillis());
          
         client_st.setId(oxu.registerFilestore(client_st,ContextTest.DummyMasterCredentials()).getId());
         
-        Filestore[] srv_stores = oxu.listFilestore("file:/tmp/disc_*",ContextTest.DummyMasterCredentials());
+        Filestore[] srv_stores = oxu.listFilestore("*disc_*",ContextTest.DummyMasterCredentials());
         
         assertTrue("Expected list size > 0 ",srv_stores.length>0);
     }
@@ -537,11 +542,11 @@ public class UtilTest extends AbstractTest {
     public void testUnregisterFilestore() throws Exception {
         OXUtilInterface oxu = getUtilClient();
         
-        Filestore client_st  = getTestFilestoreObject("testcase_registerfilestore_disc_"+System.currentTimeMillis(),"file:/tmp/disc_"+System.currentTimeMillis());
+        Filestore client_st  = getTestFilestoreObject("testcase_registerfilestore_disc_"+System.currentTimeMillis(),"disc_"+System.currentTimeMillis());
          
         client_st.setId(oxu.registerFilestore(client_st,ContextTest.DummyMasterCredentials()).getId());
         
-        Filestore[] srv_stores = oxu.listFilestore("file:/tmp/disc_*",ContextTest.DummyMasterCredentials());
+        Filestore[] srv_stores = oxu.listFilestore("*disc_*",ContextTest.DummyMasterCredentials());
         
         // now check if added filestore was correctly registered to the system        
         boolean found_store = false;
@@ -560,7 +565,7 @@ public class UtilTest extends AbstractTest {
         // now unregister and search again
         oxu.unregisterFilestore(new Filestore(client_st.getId()),ContextTest.DummyMasterCredentials());
         
-        srv_stores = oxu.listFilestore("file:/tmp/disc_*",ContextTest.DummyMasterCredentials());
+        srv_stores = oxu.listFilestore("*disc_*",ContextTest.DummyMasterCredentials());
         
         // now check if added filestore was correctly registered to the system        
         found_store = false;
